@@ -94,13 +94,15 @@ class ClientLoop(object):
 
     def set_os_permissions(self):
         try:
-            robot_uid, robot_gid = pwd.getpwnam('robot')[2:4]
+            robot_uid, robot_gid = pwd.getpwnam('nobody')[2:4]
         except KeyError:
             pass  # for dev version
         else:
             try:
+                os.setgroups([])
                 os.setgid(robot_gid)
                 os.setuid(robot_uid)
+                os.umask(0o777)
             except OSError:
                 pass  # for dev version
 
